# autodeploy_template/__init__.py
# from <parent_folder>.<python_file> import (
#     <every_class>, 
#     <every_function>, 
#     <every_variable>,
# )

# import upload_package.upload as upload
import robin_sd_upload.module_1 as module_1

module_1.bar()
print(module_1.variable)
